--
-- maxRpm
-- This is the specialization for maxRpm
--
-- original script:
-- upsideDown
-- 11.07.2013
-- 
--



maxRpm = {};
local maxRPM_directory = g_currentModDirectory;

function maxRpm.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function maxRpm:load(xmlFile)

	self.maxRpmStdValue = self.motor.maxRpm[3];
	self.maxRpmFactor = 1.0;
	
	self.rpmLimiterHUD = Overlay:new("rpmLimiterHUD", Utils.getFilename("rpmLimiterHUD.dds", maxRPM_directory),  0.402, 0.05238, 0.10, 0.04);
end;

function maxRpm:delete()
end;

function maxRpm:mouseEvent(posX, posY, isDown, isUp, button)
end;

function maxRpm:keyEvent(unicode, sym, modifier, isDown)
end;

function maxRpm:update(dt)
	if self:getIsActiveForInput(false) then
		
		if self.motor.speedLevel == 0 then
			local dx = 0;
			if InputBinding.isPressed(InputBinding.maxRpm_minus) then
				dx = -0.0003*dt;
			end
			if InputBinding.isPressed(InputBinding.maxRpm_plus) then
				dx = 0.0003*dt;
			end
			if dx ~= 0 then
				self.maxRpmFactor = self.maxRpmFactor + dx;
				if self.maxRpmFactor > 1.0 then
					self.maxRpmFactor = 1.0;
				end
				if self.maxRpmFactor < 0.01 then
					self.maxRpmFactor = 0.01;
				end;
				if g_server ~= nil then
					g_server:broadcastEvent(maxRpmEvent:new(self, self.maxRpmFactor), nil, nil, self);
				else
					g_client:getServerConnection():sendEvent(maxRpmEvent:new(self, self.maxRpmFactor));
				end;
			end;
		end;
	end
end;


function maxRpm:updateTick(dt)
	if self.motor.speedLevel == 0 then
		if self.maxRpmFactor == 1.0 then
			self.motor.maxRpmOverride = nil;
		else
			self.motor.maxRpmOverride =  self.maxRpmStdValue *  self.maxRpmFactor;
		end;
	else
		if self.motor.maxRpmOverride ==  self.maxRpmStdValue *  self.maxRpmFactor then
			self.motor.maxRpmOverride = nil;
		end;
	end
end;

function maxRpm:readStream(streamId, connection)
    self.maxRpmFactor = streamReadFloat32(streamId)
end;

function maxRpm:writeStream(streamId, connection)
  streamWriteFloat32(streamId, self.maxRpmFactor)

end;

function maxRpm:draw()
	self.rpmLimiterHUD:render();
	setTextAlignment(RenderText.ALIGN_RIGHT);
	if self.motor.speedLevel == 0 then
		setTextBold(true);
		setTextColor(.8,.8,.8,1);
	else
		setTextBold(false);
		setTextColor(.4,.4,.4,1);
	end
	renderText(.402+ 0.085,0.05238 + 0.010,0.022, string.format("%d%%", self.maxRpmFactor*100));

end;





maxRpmEvent = {};
  maxRpmEvent_mt = Class(maxRpmEvent, Event);
  
  InitEventClass(maxRpmEvent, "maxRpmEvent");
  
  function maxRpmEvent:emptyNew()
      local self = Event:new(maxRpmEvent_mt);
      return self;
  end;
  
  function maxRpmEvent:new(object,maxRpm)
      local self = maxRpmEvent:emptyNew()
      self.maxRpm = maxRpm;
	  
      self.object = object;
      return self;
  end;
  
  function maxRpmEvent:readStream(streamId, connection)
      local id = streamReadInt32(streamId);
      self.maxRpm = streamReadFloat32(streamId);
	  
	  self.object = networkGetObject(id);
      self:run(connection);
  end;
  
  function maxRpmEvent:writeStream(streamId, connection)
      streamWriteInt32(streamId, networkGetObjectId(self.object));
	  streamWriteFloat32(streamId, self.maxRpm);
	 
  end;
  
  function maxRpmEvent:run(connection)
	  self.object.maxRpmFactor = self.maxRpm;	  
	  
      if not connection:getIsServer() then
          g_server:broadcastEvent(maxRpmEvent:new(self.object, self.maxRpm), nil, connection, self.object);
      end;
  end;
